@@ -1,8 +1,12 @@
 import tweepy as tw
-from tunga.retrieval import config
 
-auth = tw.OAuthHandler(config.api_key, config.api_secret, )
-auth.set_access_token(config.access_token, config.token_secret)
+api_key = 'imW937M6khWYK3utt6rgUNwC9'
+api_secret = 'NHrbDvcnvoqOIJjWKhUXZPAfsToM3k9X8mQoslGF0w24xiJknR'
+access_token = '246202949-DZ5kRviZM7cBJFyp1gMZw3GytoIsbGMBhNt3pGOW'
+token_secret = 'n7G3SblCHd9URjIAugRRBZKqYLUVyDYtf39vuYvgaqE9q'
+
+auth = tw.OAuthHandler(api_key, api_secret, )
+auth.set_access_token(access_token, token_secret)
 api = tw.API(auth)
 
 
